@@ -37,3 +37,7 @@ def run(runner, debug=False):
 
         respond(e, str(e), success=False)
         exit(1)
+
+def execute(obj, args):
+    method = getattr(obj, args.action)
+    run(lambda: call(method, vars(args)), args.debug)
